@@ -156,11 +156,11 @@ def itt2d(shape, dd, extend=1.00):
     sly = SL(shape[1], extend=extend)
 
     vv = np.linspace(0, shape[0], dd + 1)
-    vx = np.array(0.5 * (vv[:-1] + vv[1:]), dtype=np.int)
-    dx = np.array(0.5 * (vv[1:] - vv[:-1]), dtype=np.int)
+    vx = np.array(0.5 * (vv[:-1] + vv[1:]), dtype=int)
+    dx = np.array(0.5 * (vv[1:] - vv[:-1]), dtype=int)
     vv = np.linspace(0, shape[1], dd + 1)
-    vy = np.array(0.5 * (vv[:-1] + vv[1:]), dtype=np.int)
-    dy = np.array(0.5 * (vv[1:] - vv[:-1]), dtype=np.int)
+    vy = np.array(0.5 * (vv[:-1] + vv[1:]), dtype=int)
+    dy = np.array(0.5 * (vv[1:] - vv[:-1]), dtype=int)
 
     return product(map(slx, zip(vx, dx)), map(sly, zip(vy, dy)))
 
@@ -323,7 +323,7 @@ def inpaint(array, sigma=None, logger=None, update_in_place=False, fill_corners=
                     else:
                         nn = xi.shape[0]
                         max_interpolation_points = 1500000
-                        nn_blocks = np.int(np.ceil(nn / max_interpolation_points))
+                        nn_blocks = int(np.ceil(nn / max_interpolation_points))
                         ss = np.linspace(0, nn, nn_blocks, dtype=np.int, endpoint=True)
                         for ii, (j1, j2) in enumerate(zip(ss[:-1], ss[1:])):
                             logger.info("%i / %i ,%i,%i" % (ii, nn_blocks, j1, j2))
@@ -424,7 +424,7 @@ if __name__ == "__main__":
     s2aot[s2aot < 0.0] = np.nan
 
     mask = None
-    # mask = np.empty(shape,dtype=np.bool)
+    # mask = np.empty(shape,dtype=bool)
     # mask[:] = False
     # mask[500:9000,1000:6000] = True
 
