@@ -35,7 +35,7 @@ from numbers import Number
 import matplotlib
 import matplotlib.pyplot as plt
 import numpy as np
-import gdal
+from osgeo import gdal
 
 from .AC.RtFo import Rho2Rj_const, Rj2RhoJ_const, RtFo
 from .AC.ACG import instrument_subset
@@ -790,7 +790,7 @@ def ac_gms(s2img, options, logger=None, script=True):
     else:
         logger.info("Novelty detector is neither available at user-provided path nor in default tables path.")
         logger.info("Download novelty detector from google drive and store at default tables path.")
-        url = 'https://drive.google.com/uc?export=download&id=1k0m5fJCBiJbVAoPQPfN0iqn3LnI3UVvu'
+        url = 'https://drive.google.com/uc?export=download&id=1T9H3skt8uDUujCF4hSFV3ghalFnT_xd7'
         gdown.download(url, default_nov_det_path, quiet=False)
         # check if novelty detector was properly downloaded
         try:
@@ -801,8 +801,8 @@ def ac_gms(s2img, options, logger=None, script=True):
             raise AssertionError("Novelty detector was not properly downloaded. Please restart AC and try again.")
         except FileNotFoundError:
             options["processing"]["status"] = 1
-            raise FileNotFoundError("Novelty detector could not be properly downloaded, the path provided is incorrect. "
-                                    "Please restart AC and try again.")
+            raise FileNotFoundError("Novelty detector could not be properly downloaded, the path provided is "
+                                    "incorrect. Please restart AC and try again.")
 
         options["cld_mask"]["novelty_detector"] = default_nov_det_path
 
